Index: scripts/slave/recipes/flutter/engine.py |
diff --git a/scripts/slave/recipes/flutter/engine.py b/scripts/slave/recipes/flutter/engine.py |
index 1667757f405e4149b0fa5264a28d37a5e8fa92a1..93c77fe4a9972ccdd509c58cde40936c03a9845e 100644 |
--- a/scripts/slave/recipes/flutter/engine.py |
+++ b/scripts/slave/recipes/flutter/engine.py |
@@ -19,9 +19,9 @@ DEPS = [ |
BUCKET_NAME = 'flutter_infra' |
def GetCloudPath(api, path): |
- # TODO(eseidel): api.bot_update.properties is supposedly a known api wart. |
- # iannucci says it will be improved at some point. |
- git_hash = api.bot_update.properties['got_engine_revision'] |
+ # TODO(eseidel): api.bot_update.last_returned_properties is supposedly a known |
+ # api wart. iannucci says it will be improved at some point. |
+ git_hash = api.bot_update.last_returned_properties['got_engine_revision'] |
return 'flutter/%s/%s' % (git_hash, path) |